pyprocar.io.lobster.LobsterParser — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.io.lobster.LobsterParser

class pyprocar.io.lobster.LobsterParser(dirname='', code='qe', lobsterin='lobsterin', lobsterout='lobsterout', scfIn_filename='scf.in', outcar='OUTCAR', poscar='POSCAR', procar='PROCAR', dos_interpolation_factor=None)

  The class helps parse the information from a lobster calculation

  Parameters:

    - dirname (str, optional) – The directory name for the calculation, by default “”

    - code (str, optional) – The code name, by default ‘qe’

    - lobsterin (str, optional) – The lobster in put filename, by default ‘lobsterin’

    - lobsterout (str, optional) – The lobster output filename, by default ‘lobsterout’

    - scfIn_filename (str, optional) – The scf.in file for QE calculations, by default “scf.in”

    - outcar (str, optional) – The outcar for vasp calculations, by default ‘OUTCAR’

    - poscar (str, optional) – The poscar for vasp calculations, by default ‘POSCAR’

    - procar (str, optional) – The procar for vasp calculations, by default ‘PROCAR’

    - dos_interpolation_factor (_type_, optional) – The interpolation factor on the density of states, by default None

  Methods

  `LobsterParser.__init__`([dirname, code, ...]) |
  `LobsterParser.dos_parametric`([atoms, ...]) | This function sums over the list of atoms and orbitals given for example dos_paramateric(atoms=[0,1,2],orbitals=[1,2,3],spin=[0,1]) will sum all the projections of atoms 0,1,2 and all the orbitals of 1,2,3 (px,py,pz) and return separatly for the 2 spins as a DensityOfStates object from pychemia.visual.DensityofStates
  `LobsterParser.parse_structure`([outcar, ...]) | A method to parse the electronic sturcutue information

  Attributes

  `LobsterParser.dos` | Initializes the pyprocar.core.DensityOfStates
  `LobsterParser.dos_projected` | Returns the projected DOS as a multi-dimentional array, to be used in the pyprocar.core.DensityOfStates object
  `LobsterParser.dos_to_dict` | Returns the complete density (total,projected) of states as a python dictionary
  `LobsterParser.dos_total` | Returns the density of states total as a dict.
  `LobsterParser.final_structure` | Returns a the last element of a list of pyprocar.core.Structure
  `LobsterParser.initial_structure` | Returns a the first element of a list of pyprocar.core.Structure
  `LobsterParser.species` | Returns the species of the calculation
  `LobsterParser.structure` | Returns a the last element of a list of pyprocar.core.Structure
  `LobsterParser.structures` | Returns a list of pyprocar.core.Structure